@@ -7,6 +7,8 @@ Tests for decompression of single chunks.
 """
 import brotli
 
+import pytest
+
 
 def test_decompression(simple_compressed_file):
     """
@@ -31,6 +33,7 @@ def test_decompressobj(simple_compressed_file):
     o = brotli.Decompressor()
     data = o.decompress(compressed_data)
     data += o.flush()
+    data += o.finish()
 
     assert data == uncompressed_data
 
@@ -51,5 +54,26 @@ def test_drip_feed(simple_compressed_file):
         outdata.append(o.decompress(compressed_data[i:i+1]))
 
     outdata.append(o.flush())
+    outdata.append(o.finish())
 
     assert b''.join(outdata) == uncompressed_data
+
+
+@pytest.mark.parametrize('exception_cls', [brotli.Error, brotli.error])
+def test_streaming_decompression_fails_properly_on_garbage(exception_cls):
+    """
+    Garbage data properly fails decompression.
+    """
+    o = brotli.Decompressor()
+    with pytest.raises(exception_cls):
+        o.decompress(b'some random garbage')
+
+
+@pytest.mark.parametrize('exception_cls', [brotli.Error, brotli.error])
+@pytest.mark.parametrize('bogus', (b'some random garbage', b'bogus'))
+def test_decompression_fails_properly_on_garbage(bogus, exception_cls):
+    """
+    Garbage data properly fails decompression.
+    """
+    with pytest.raises(exception_cls):
+        brotli.decompress(bogus)
